==> gatsby-transformer-wpcontent-0.1.13.tgz: package/gatsby-node.js <==
const path = require("path");
const fs = require("fs");
const crypto = require('crypto');

const _ = require("lodash")
//const slash = require('slash')
//const url = require("url")
//const queryString = require(`query-string`)
const cheerio = require("cheerio");
//const chalk = require(`chalk`)

const { GraphQLJSON } = require(`gatsby/graphql`);

const {
    embedCode,
    highlightCode,
    rewriteLinks,
    processImages,
    addSectionAnchors,
    addIdsForIndexableFragments,
    fixClosingTagsInHighlightedCode,
} = require(`./src/utils`)

const {
    DEFAULT_OPTIONS,
    imageClass,
    imageBackgroundClass,
    imageWrapperClass,
} = require(`./src/constants`)




//###########################################################################
//# get Html Sharp
//###########################################################################
const getHtmlBeta = async (content, actions, createNodeId, getNodesByType, pathPrefix, store,cache, options, reporter, variables) => {

    const { createNode } = actions

    if (!variables)
        variables = []

    // For correct highlighting of HTML code, we need to disable
    // entity resolution in cheerio and then patch this in the
    // serialized HTML, see fixClosingTagsInHighlightedCode() below.
    let $ = cheerio.load(content, { decodeEntities: false });
    $ = await processImages($, pathPrefix, createNode, getNodesByType, reporter, store, cache, variables, options);
    $ = rewriteLinks($);
    $ = addSectionAnchors($);
    //$ = embedCode($, node.dir, variables, reporter);
    $ = highlightCode($);
    $ = addIdsForIndexableFragments($);

    let html = fixClosingTagsInHighlightedCode($.html());
    //var ss = createMapReplacer(variables)
    //reporter.info( $.html() )
    //html = replaceVariables(html, createMapReplacer(variables));


    return $(`body`).html();

}

const createSchemaCustomization = ({ actions, reporter}, pluginOptions = {}) => {
    actions.createResolverContext({getHtmlBeta})

}


const createResolvers = ({
                             actions,
                             cache,
                             pathPrefix,
                             getNodesByType,
                             createNodeId,
                             createContentDigest,
                             loadNodeContent,
                             createResolvers,
                             store,
                             reporter,
                             variables
                         }, pluginOptions) => {

    const { plugins = [] } = pluginOptions
    const options = _.defaults(pluginOptions, { pathPrefix }, DEFAULT_OPTIONS)

    //console.log('NODE >>> ', variables)
    //console.log('Plugin Options >>> ',pluginOptions)

    //console.log(getNodesByType(`PrismicPostDataContent`))

    // This allows subplugins to use Node APIs bound to `gatsby-transformer-remark`
    // to customize the GraphQL schema. This makes it possible for subplugins to
    // modify types owned by `gatsby-transformer-remark`.
    /*plugins.forEach(plugin => {
        const resolvedPlugin = require(plugin.resolve)
        if (typeof resolvedPlugin.createResolvers === `function`) {
            resolvedPlugin.createResolvers(
                options,
                plugin.pluginOptions
            )
        }
        /*if (typeof resolvedPlugin.addLazyLoad === `function`) {
            resolvedPlugin.addLazyLoad(
                //options,
                plugin.pluginOptions
            )
        }* /
        //console.log('PLUGIN >>> ',plugin)
    })*/


    const resolvers = {
        WPGraphQL_Post: {
            //data: {
            //type: [`Node`],
            content: {
                type: [`String`],
                resolve: (source, args, context, info) => {
                    var html = source.content
                    //console.log(context)
                    if (!html)
                        return source.content

                    const htmlSharped = context.sekmetGatsbyTransformerWpcontent.getHtmlBeta( html, actions, createNodeId, getNodesByType, pathPrefix, store, cache, options, reporter, variables )

                    return htmlSharped ? [htmlSharped] : html
                }
            }
            //}
        }
    }



    createResolvers(resolvers)

}



const onPreExtractQueries = async ({ store, getNodesByType }) => {
    const program = store.getState().program

    // Check if there are any ImageSharp nodes. If so add fragments for ImageSharp.
    // The fragment will cause an error if there are no ImageSharp nodes.
    //if (getNodesByType(`GraphQLSource`).length == 0) {
    //    return
    //}

    ///console.log(getNodesByType(`PrismicPostDataContent`))

    // We have ImageSharp nodes so let's add our fragments to .cache/fragments.
    /*await fs.copy(
        require.resolve(`gatsby-transformer-sharp/src/fragments.js`),
        `${program.directory}/.cache/fragments/image-sharp-fragments.js`
    )*/
}

const onPreBootstrap = ({ reporter },  variables ) => {
    try {
        //console.log('variables ============ ', variables)
        //validateVariables(variables);
    } catch (e) {
        reporter.panic(e);
    }
};
exports.createSchemaCustomization = createSchemaCustomization;
exports.createResolvers = createResolvers;
exports.onPreExtractQueries = onPreExtractQueries;
exports.onPreBootstrap = onPreBootstrap;
//exports.onCreateNode = onCreateNode;

==> gatsby-transformer-wpcontent-0.1.14.tgz: package/gatsby-node.js <==
const path = require("path");
const fs = require("fs");
const crypto = require('crypto');

const _ = require("lodash")
//const slash = require('slash')
//const url = require("url")
//const queryString = require(`query-string`)
const cheerio = require("cheerio");
//const chalk = require(`chalk`)

const { GraphQLJSON } = require(`gatsby/graphql`);

const {
    embedCode,
    highlightCode,
    rewriteLinks,
    processImages,
    addSectionAnchors,
    addIdsForIndexableFragments,
    fixClosingTagsInHighlightedCode,
} = require(`./src/utils`)

const {
    DEFAULT_OPTIONS,
    imageClass,
    imageBackgroundClass,
    imageWrapperClass,
} = require(`./src/constants`)




//###########################################################################
//# get Html Sharp
//###########################################################################
const getHtmlBeta = async (content, actions, createNodeId, getNodesByType, pathPrefix, store,cache, options, reporter, variables) => {

    const { createNode } = actions

    if (!variables)
        variables = []

    // For correct highlighting of HTML code, we need to disable
    // entity resolution in cheerio and then patch this in the
    // serialized HTML, see fixClosingTagsInHighlightedCode() below.
    let $ = cheerio.load(content, { decodeEntities: false });
    $ = await processImages($, pathPrefix, createNode, getNodesByType, reporter, store, cache, variables, options);
    $ = rewriteLinks($);
    $ = addSectionAnchors($);
    //$ = embedCode($, node.dir, variables, reporter);
    $ = highlightCode($);
    $ = addIdsForIndexableFragments($);

    let html = fixClosingTagsInHighlightedCode($.html());
    //var ss = createMapReplacer(variables)
    //reporter.info( $.html() )
    //html = replaceVariables(html, createMapReplacer(variables));


    return $(`body`).html();

}

const createSchemaCustomization = ({ actions, reporter}, pluginOptions = {}) => {
    actions.createResolverContext({getHtmlBeta})

}


const createResolvers = ({
                             actions,
                             cache,
                             pathPrefix,
                             getNodesByType,
                             createNodeId,
                             createContentDigest,
                             loadNodeContent,
                             createResolvers,
                             store,
                             reporter,
                             variables
                         }, pluginOptions) => {

    const { plugins = [] } = pluginOptions
    const options = _.defaults(pluginOptions, { pathPrefix }, DEFAULT_OPTIONS)

    //console.log('NODE >>> ', variables)
    //console.log('Plugin Options >>> ',pluginOptions)

    //console.log(getNodesByType(`PrismicPostDataContent`))

    // This allows subplugins to use Node APIs bound to `gatsby-transformer-remark`
    // to customize the GraphQL schema. This makes it possible for subplugins to
    // modify types owned by `gatsby-transformer-remark`.
    plugins.forEach(plugin => {
        const resolvedPlugin = require(plugin.resolve)
        if (typeof resolvedPlugin.createResolvers === `function`) {
            resolvedPlugin.createResolvers(
                options,
                plugin.pluginOptions
            )
        }
        /*if (typeof resolvedPlugin.addLazyLoad === `function`) {
            resolvedPlugin.addLazyLoad(
                //options,
                plugin.pluginOptions
            )
        }*/
        //console.log('PLUGIN >>> ',plugin)
    })


    const resolvers = {
        WPGraphQL_Post: {
            //data: {
            //type: [`Node`],
            content: {
                type: [`String`],
                resolve: (source, args, context, info) => {
                    var html = source.content
                    //console.log(context)
                    if (!html)
                        return source.content

                    const htmlSharped = context.sekmetGatsbyTransformerWpcontent.getHtmlBeta( html, actions, createNodeId, getNodesByType, pathPrefix, store, cache, options, reporter, variables )

                    return htmlSharped ? [htmlSharped] : html
                }
            }
            //}
        }
    }



    createResolvers(resolvers)

}



const onPreExtractQueries = async ({ store, getNodesByType }) => {
    const program = store.getState().program

    // Check if there are any ImageSharp nodes. If so add fragments for ImageSharp.
    // The fragment will cause an error if there are no ImageSharp nodes.
    //if (getNodesByType(`GraphQLSource`).length == 0) {
    //    return
    //}

    ///console.log(getNodesByType(`PrismicPostDataContent`))

    // We have ImageSharp nodes so let's add our fragments to .cache/fragments.
    /*await fs.copy(
        require.resolve(`gatsby-transformer-sharp/src/fragments.js`),
        `${program.directory}/.cache/fragments/image-sharp-fragments.js`
    )*/
}

const onPreBootstrap = ({ reporter },  variables ) => {
    try {
        //console.log('variables ============ ', variables)
        //validateVariables(variables);
    } catch (e) {
        reporter.panic(e);
    }
};
exports.createSchemaCustomization = createSchemaCustomization;
exports.createResolvers = createResolvers;
exports.onPreExtractQueries = onPreExtractQueries;
exports.onPreBootstrap = onPreBootstrap;
//exports.onCreateNode = onCreateNode;
